@@ -5,6 +5,9 @@
 // Copyright 1998-2001 by Neil Hodgson <neilh@scintilla.org>
 // The License.txt file describes the conditions under which this software may be distributed.
 
+#ifndef DIRECTOREXTENSION_H
+#define DIRECTOREXTENSION_H
+
 class DirectorExtension : public Extension {
 private:
 	DirectorExtension() : inputWatcher(-1), inputChannel(0), host(0) {} // Singleton
@@ -47,3 +50,4 @@ private:
 	ExtensionAPI *host;
 };
 
+#endif
