@@ -9,6 +9,7 @@
 #include <time.h>
 
 #include <string>
+#include <chrono>
 #include <sstream>
 
 #include <gtk/gtk.h>
@@ -100,7 +101,7 @@ void Window::SetPosition(Rectangle rc) {
 }
 
 Rectangle Window::GetClientPosition() {
-	// On GTK+, the client position is the window position
+	// On GTK, the client position is the window position
 	return GetPosition();
 }
 
@@ -143,7 +144,7 @@ void Menu::Show(Point pt G_GNUC_UNUSED, Window &) {
 	GtkMenu *widget = static_cast<GtkMenu *>(mid);
 	gtk_widget_show_all(GTK_WIDGET(widget));
 #if GTK_CHECK_VERSION(3,22,0)
-	// Rely on GTK+ to do the right thing with positioning
+	// Rely on GTK to do the right thing with positioning
 	gtk_menu_popup_at_pointer(widget, NULL);
 #else
 	int screenHeight = gdk_screen_height();
@@ -166,28 +167,6 @@ void Menu::Show(Point pt G_GNUC_UNUSED, Window &) {
 #endif
 }
 
-ElapsedTime::ElapsedTime() {
-	GTimeVal curTime;
-	g_get_current_time(&curTime);
-	bigBit = curTime.tv_sec;
-	littleBit = curTime.tv_usec;
-}
-
-double ElapsedTime::Duration(bool reset) {
-	GTimeVal curTime;
-	g_get_current_time(&curTime);
-	long endBigBit = curTime.tv_sec;
-	long endLittleBit = curTime.tv_usec;
-	double result = 1000000.0 * (endBigBit - bigBit);
-	result += endLittleBit - littleBit;
-	result /= 1000000.0;
-	if (reset) {
-		bigBit = endBigBit;
-		littleBit = endLittleBit;
-	}
-	return result;
-}
-
 sptr_t ScintillaPrimitive::Send(unsigned int msg, uptr_t wParam, sptr_t lParam) {
 	return scintilla_send_message(SCINTILLA(GetID()), msg, wParam, lParam);
 }
@@ -211,4 +190,8 @@ bool IsDBCSLeadByte(int codePage, char ch) {
 	return false;
 }
 
+void SleepMilliseconds(int sleepTime) {
+	g_usleep(sleepTime * 1000);
+}
+
 }
