@@ -463,7 +463,7 @@ void SurfaceImpl::Polygon(Point *pts, size_t npts, ColourDesired fore,
 void SurfaceImpl::RectangleDraw(PRectangle rc, ColourDesired fore, ColourDesired back) {
 	if (context) {
 		cairo_rectangle(context, rc.left + 0.5, rc.top + 0.5,
-				rc.right - rc.left - 1, rc.bottom - rc.top - 1);
+				rc.Width() - 1, rc.Height() - 1);
 		PenColour(back);
 		cairo_fill_preserve(context);
 		PenColour(fore);
@@ -476,35 +476,19 @@ void SurfaceImpl::FillRectangle(PRectangle rc, ColourDesired back) {
 	if (context && (rc.left < maxCoordinate)) {	// Protect against out of range
 		rc.left = std::round(rc.left);
 		rc.right = std::round(rc.right);
-		cairo_rectangle(context, rc.left, rc.top,
-				rc.right - rc.left, rc.bottom - rc.top);
+		cairo_rectangle(context, rc.left, rc.top, rc.Width(), rc.Height());
 		cairo_fill(context);
 	}
 }
 
 void SurfaceImpl::FillRectangle(PRectangle rc, Surface &surfacePattern) {
-	SurfaceImpl &surfi = static_cast<SurfaceImpl &>(surfacePattern);
-	const bool canDraw = surfi.psurf != nullptr;
-	if (canDraw) {
-		PLATFORM_ASSERT(context);
+	SurfaceImpl &surfi = dynamic_cast<SurfaceImpl &>(surfacePattern);
+	if (context && surfi.psurf) {
 		// Tile pattern over rectangle
-		// Currently assumes 8x8 pattern
-		constexpr int widthPat = 8;
-		constexpr int heightPat = 8;
-		const IntegerRectangle irc(rc);
-		for (int xTile = irc.left; xTile < irc.right; xTile += widthPat) {
-			const int widthx = (xTile + widthPat > irc.right) ? irc.right - xTile : widthPat;
-			for (int yTile = irc.top; yTile < irc.bottom; yTile += heightPat) {
-				const int heighty = (yTile + heightPat > irc.bottom) ? irc.bottom - yTile : heightPat;
-				cairo_set_source_surface(context, surfi.psurf, xTile, yTile);
-				cairo_rectangle(context, xTile, yTile, widthx, heighty);
-				cairo_fill(context);
-			}
-		}
-	} else {
-		// Something is wrong so try to show anyway
-		// Shows up black because colour not allocated
-		FillRectangle(rc, ColourDesired(0));
+		cairo_set_source_surface(context, surfi.psurf, rc.left, rc.top);
+		cairo_pattern_set_extend(cairo_get_source(context), CAIRO_EXTEND_REPEAT);
+		cairo_rectangle(context, rc.left, rc.top, rc.Width(), rc.Height());
+		cairo_fill(context);
 	}
 }
 
@@ -527,7 +511,7 @@ void SurfaceImpl::RoundedRectangle(PRectangle rc, ColourDesired fore, ColourDesi
 	}
 }
 
-static void PathRoundRectangle(cairo_t *context, double left, double top, double width, double height, int radius) noexcept {
+static void PathRoundRectangle(cairo_t *context, double left, double top, double width, double height, double radius) noexcept {
 	constexpr double degrees = kPi / 180.0;
 
 	cairo_new_sub_path(context);
@@ -548,9 +532,9 @@ void SurfaceImpl::AlphaRectangle(PRectangle rc, int cornerSize, ColourDesired fi
 				      cdFill.GetBlue() / 255.0,
 				      alphaFill / 255.0);
 		if (cornerSize > 0)
-			PathRoundRectangle(context, rc.left + 1.0, rc.top + 1.0, rc.right - rc.left - 2.0, rc.bottom - rc.top - 2.0, cornerSize);
+			PathRoundRectangle(context, rc.left + 1.0, rc.top + 1.0, rc.Width() - 2.0, rc.Height() - 2.0, cornerSize);
 		else
-			cairo_rectangle(context, rc.left + 1.0, rc.top + 1.0, rc.right - rc.left - 2.0, rc.bottom - rc.top - 2.0);
+			cairo_rectangle(context, rc.left + 1.0, rc.top + 1.0, rc.Width() - 2.0, rc.Height() - 2.0);
 		cairo_fill(context);
 
 		const ColourDesired cdOutline(outline.AsInteger());
@@ -560,9 +544,9 @@ void SurfaceImpl::AlphaRectangle(PRectangle rc, int cornerSize, ColourDesired fi
 				      cdOutline.GetBlue() / 255.0,
 				      alphaOutline / 255.0);
 		if (cornerSize > 0)
-			PathRoundRectangle(context, rc.left + 0.5, rc.top + 0.5, rc.right - rc.left - 1, rc.bottom - rc.top - 1, cornerSize);
+			PathRoundRectangle(context, rc.left + 0.5, rc.top + 0.5, rc.Width() - 1, rc.Height() - 1, cornerSize);
 		else
-			cairo_rectangle(context, rc.left + 0.5, rc.top + 0.5, rc.right - rc.left - 1, rc.bottom - rc.top - 1);
+			cairo_rectangle(context, rc.left + 0.5, rc.top + 0.5, rc.Width() - 1, rc.Height() - 1);
 		cairo_stroke(context);
 	}
 }
@@ -613,7 +597,7 @@ void SurfaceImpl::DrawRGBAImage(PRectangle rc, int width, int height, const unsi
 
 	cairo_surface_t *psurfImage = cairo_image_surface_create_for_data(&image[0], CAIRO_FORMAT_ARGB32, width, height, stride);
 	cairo_set_source_surface(context, psurfImage, rc.left, rc.top);
-	cairo_rectangle(context, rc.left, rc.top, rc.right-rc.left, rc.bottom-rc.top);
+	cairo_rectangle(context, rc.left, rc.top, rc.Width(), rc.Height());
 	cairo_fill(context);
 
 	cairo_surface_destroy(psurfImage);
@@ -636,7 +620,7 @@ void SurfaceImpl::Copy(PRectangle rc, Point from, Surface &surfaceSource) {
 		PLATFORM_ASSERT(context);
 		cairo_set_source_surface(context, surfi.psurf,
 					 rc.left - from.x, rc.top - from.y);
-		cairo_rectangle(context, rc.left, rc.top, rc.right-rc.left, rc.bottom-rc.top);
+		cairo_rectangle(context, rc.left, rc.top, rc.Width(), rc.Height());
 		cairo_fill(context);
 	}
 }
@@ -969,7 +953,7 @@ XYPOSITION SurfaceImpl::AverageCharWidth(Font &font_) {
 
 void SurfaceImpl::SetClip(PRectangle rc) {
 	PLATFORM_ASSERT(context);
-	cairo_rectangle(context, rc.left, rc.top, rc.right, rc.bottom);
+	cairo_rectangle(context, rc.left, rc.top, rc.Width(), rc.Height());
 	cairo_clip(context);
 }
 
