@@ -8,9 +8,7 @@
 #ifndef WORDLIST_H
 #define WORDLIST_H
 
-#ifdef SCI_NAMESPACE
 namespace Scintilla {
-#endif
 
 /**
  */
@@ -24,19 +22,17 @@ class WordList {
 public:
 	explicit WordList(bool onlyLineEnds_ = false);
 	~WordList();
-	operator bool() const;
-	bool operator!=(const WordList &other) const;
-	int Length() const;
-	void Clear();
-	void Set(const char *s);
-	bool InList(const char *s) const;
-	bool InListAbbreviated(const char *s, const char marker) const;
-	bool InListAbridged(const char *s, const char marker) const;
-	const char *WordAt(int n) const;
+	operator bool() const noexcept;
+	bool operator!=(const WordList &other) const noexcept;
+	int Length() const noexcept;
+	void Clear() noexcept;
+	bool Set(const char *s);
+	bool InList(const char *s) const noexcept;
+	bool InListAbbreviated(const char *s, const char marker) const noexcept;
+	bool InListAbridged(const char *s, const char marker) const noexcept;
+	const char *WordAt(int n) const noexcept;
 };
 
-#ifdef SCI_NAMESPACE
 }
-#endif
 
 #endif
