@@ -1,3 +1,4 @@
+#!/usr/bin/env python2
 import distutils.sysconfig
 import getopt
 import glob
@@ -8,6 +9,9 @@ import subprocess
 import stat
 import sys
 
+# ScintillaEditPy can only be built against Python 2.x so fail if Python 3.x
+assert sys.version_info < (3,0), "sepbuild.py requires Python 2.x"
+
 sys.path.append(os.path.join("..", "ScintillaEdit"))
 import WidgetGen
 
@@ -39,6 +43,7 @@ def textFromRun(args):
 	proc = subprocess.Popen(args, shell=isinstance(args, str), stdout=subprocess.PIPE)
 	(stdoutdata, stderrdata) = proc.communicate()
 	if proc.returncode:
+		print("Warning  - failed to run '" + " ".join(args) + "'")
 		raise OSError(proc.returncode)
 	return stdoutdata
 
@@ -172,7 +177,7 @@ class SepBuilder:
 		self.qtStyleInterface = True
 
 	def _setPySideBase(self, base):
-		
+
 		self.PySideBase = base
 		def _try_pkgconfig(var, package, *relpath):
 			try:
@@ -209,7 +214,7 @@ class SepBuilder:
 		f = WidgetGen.readInterface(False)
 		os.chdir(os.path.join("..", "ScintillaEditPy"))
 		options = {"qtStyle": self.qtStyleInterface}
-		GenerateFile("typesystem_ScintillaEdit.xml.template", "typesystem_ScintillaEdit.xml", 
+		GenerateFile("typesystem_ScintillaEdit.xml.template", "typesystem_ScintillaEdit.xml",
 			"<!-- ", True, printTypeSystemFile(f, options))
 
 	def runGenerator(self):
@@ -221,7 +226,7 @@ class SepBuilder:
 			if os.path.exists(name):
 				generatorrunner = name
 				break
-				
+
 		args = [
 			generatorrunner,
 			"--generator-set=" + self.ShibokenGenerator,
@@ -235,7 +240,7 @@ class SepBuilder:
 		print(" ".join(args))
 		retcode = subprocess.call(" ".join(args), shell=True, stderr=subprocess.STDOUT)
 		if retcode:
-			print("Failed in generatorrunner", retcode)
+			print("Error - failed in generatorrunner " + str(retcode))
 			sys.exit()
 
 	def writeVariables(self):
@@ -263,7 +268,7 @@ class SepBuilder:
 	def cleanEverything(self):
 		self.generateAPI(["--clean"])
 		runProgram([self.MakeCommand, "distclean"], exitOnFailure=False)
-		filesToRemove = [self.ProInclude, "typesystem_ScintillaEdit.xml", 
+		filesToRemove = [self.ProInclude, "typesystem_ScintillaEdit.xml",
 			"../../bin/ScintillaEditPy.so", "../../bin/ScintillaConstants.py"]
 		for file in filesToRemove:
 			try:
@@ -282,7 +287,7 @@ class SepBuilder:
 	def buildEverything(self):
 		cleanGenerated = False
 		opts, args = getopt.getopt(sys.argv[1:], "hcdub",
-					["help", "clean", "debug=", 
+					["help", "clean", "debug=",
 					"underscore-names", "pyside-base="])
 		for opt, arg in opts:
 			if opt in ("-h", "--help"):
@@ -308,18 +313,18 @@ class SepBuilder:
 			self.runGenerator()
 			self.make()
 			self.copyScintillaConstants()
-			
+
 	def copyScintillaConstants(self):
-		
+
 		orig = 'ScintillaConstants.py'
 		dest = '../../bin/' + orig
 		if IsFileNewer(dest, orig):
 			return
-		
+
 		f = open(orig, 'r')
 		contents = f.read()
 		f.close()
-		
+
 		f = open(dest, 'w')
 		f.write(contents)
 		f.close()
