@@ -31,7 +31,7 @@
 # There are also problems with clang failing in the g++ 4.7 headers.
 
 # Turn off deprecation warnings if not interested:
-#export CXXFLAGS=-Wno-deprecated-declarations
+#export CXXFLAGS="-Wno-deprecated-declarations -D GLIB_DISABLE_DEPRECATION_WARNINGS"
 
 # Run commands in parallel up to number of processors
 JOBS="-j $(getconf _NPROCESSORS_ONLN)"
@@ -40,46 +40,49 @@ cd ../..
 
 # ************************************************************
 # Target 1: gcc build for GTK+ 2
-cd scintilla/test/unit
+(
+cd scintilla/test/unit || exit
 make clean
 make $JOBS test
 make clean
-cd ../../..
+)
 
-cd scintilla/lexilla/src
+(
+cd scintilla/lexilla/src || exit
 make clean
 make $JOBS
 cd ..
-cd test
+cd test || exit
 make clean
 make test
 make clean
-cd ..
-cd src
-make clean
-cd ../../..
+)
 
-cd scintilla/gtk
+(
+cd scintilla/gtk || exit
 make clean
 make $JOBS
-cd ../..
+)
 
-cd scite/gtk
+(
+cd scite/gtk || exit
 make clean
 make $JOBS
-cd ../..
+)
 
 # ************************************************************
 # Target 2: gcc build for GTK+ 3
-cd scintilla/gtk
+(
+cd scintilla/gtk || exit
 make clean
 make $JOBS GTK3=1
-cd ../..
+)
 
-cd scite/gtk
+(
+cd scite/gtk || exit
 make clean
 make $JOBS GTK3=1
-cd ../..
+)
 
 # ************************************************************
 # Target 3: Qt builds
@@ -95,72 +98,84 @@ elif hash qmake-qt4 2>/dev/null; then
 	QMAKENAME="qmake-qt4"
 fi
 
-cd scintilla/qt
-cd ScintillaEditBase
+(
+cd scintilla/qt || exit
+
+(
+cd ScintillaEditBase || exit
 $QMAKENAME
 make clean
 make $JOBS
 make distclean
-cd ..
+)
 
-cd ScintillaEdit
-python WidgetGen.py
+(
+cd ScintillaEdit || exit
+python3 WidgetGen.py
 $QMAKENAME
 make clean
 make $JOBS
 make distclean
-cd ..
+)
 
-cd ScintillaEditPy
-python sepbuild.py
-cd ../../test
-python simpleTests.py
-python lexTests.py
-python performanceTests.py
-cd ../qt/ScintillaEditPy
-python sepbuild.py --clean
-cd ..
-cd ../..
+(
+cd ScintillaEditPy || exit
+python2 sepbuild.py
+cd ../../test || exit
+python2 simpleTests.py
+python2 lexTests.py
+python2 performanceTests.py
+cd ../qt/ScintillaEditPy || exit
+python2 sepbuild.py --clean
+)
+
+)
 
 # ************************************************************
 # Target 4: clang build for GTK+ 2
-cd scintilla/gtk
+(
+cd scintilla/gtk || exit
 make clean
 make $JOBS CLANG=1
-cd ../..
+)
 
-cd scite/gtk
+(
+cd scite/gtk || exit
 make clean
 make $JOBS CLANG=1
-cd ../..
+)
 
 # ************************************************************
 # Target 5: clang build for GTK+ 3
-cd scintilla/gtk
+(
+cd scintilla/gtk || exit
 make clean
 make $JOBS CLANG=1 GTK3=1
-cd ../..
+)
 
-cd scite/gtk
+(
+cd scite/gtk || exit
 make clean
 make $JOBS CLANG=1 GTK3=1
-cd ../..
+)
 
 # ************************************************************
 # Target 6: clang analyze for GTK+ 2
-cd scintilla/gtk
+(
+cd scintilla/gtk || exit
 make clean
 make $JOBS analyze
-cd ../..
+)
 
-cd scite/gtk
+(
+cd scite/gtk || exit
 make clean
 make $JOBS analyze
 make clean
 cd ../..
-cd scintilla/gtk
+cd scintilla/gtk || exit
 make clean
-cd ../..
+)
 
 # ************************************************************
 # Target 7: cppcheck static checker
