@@ -40,22 +40,22 @@ public:
 	~Decoration() override {
 	}
 
-	bool Empty() const override {
+	bool Empty() const noexcept override {
 		return (rs.Runs() == 1) && (rs.AllSameAs(0));
 	}
-	int Indicator() const override {
+	int Indicator() const noexcept override {
 		return indicator;
 	}
-	Sci::Position Length() const override {
+	Sci::Position Length() const noexcept override {
 		return rs.Length();
 	}
-	int ValueAt(Sci::Position position) const override {
+	int ValueAt(Sci::Position position) const noexcept override {
 		return rs.ValueAt(static_cast<POS>(position));
 	}
-	Sci::Position StartRun(Sci::Position position) const override {
+	Sci::Position StartRun(Sci::Position position) const noexcept override {
 		return rs.StartRun(static_cast<POS>(position));
 	}
-	Sci::Position EndRun(Sci::Position position) const override {
+	Sci::Position EndRun(Sci::Position position) const noexcept override {
 		return rs.EndRun(static_cast<POS>(position));
 	}
 	void SetValueAt(Sci::Position position, int value) override {
@@ -64,7 +64,7 @@ public:
 	void InsertSpace(Sci::Position position, Sci::Position insertLength) override {
 		rs.InsertSpace(static_cast<POS>(position), static_cast<POS>(insertLength));
 	}
-	Sci::Position Runs() const override {
+	Sci::Position Runs() const noexcept override {
 		return rs.Runs();
 	}
 };
@@ -80,7 +80,7 @@ class DecorationList : public IDecorationList {
 	std::vector<const IDecoration*> decorationView;	// Read-only view of decorationList
 	bool clickNotified;
 
-	Decoration<POS> *DecorationFromIndicator(int indicator);
+	Decoration<POS> *DecorationFromIndicator(int indicator) noexcept;
 	Decoration<POS> *Create(int indicator, Sci::Position length);
 	void Delete(int indicator);
 	void DeleteAnyEmpty();
@@ -90,15 +90,15 @@ public:
 	DecorationList();
 	~DecorationList() override;
 
-	const std::vector<const IDecoration*> &View() const override {
+	const std::vector<const IDecoration*> &View() const noexcept override {
 		return decorationView;
 	}
 
 	void SetCurrentIndicator(int indicator) override;
-	int GetCurrentIndicator() const override { return currentIndicator; }
+	int GetCurrentIndicator() const noexcept override { return currentIndicator; }
 
 	void SetCurrentValue(int value) override;
-	int GetCurrentValue() const override { return currentValue; }
+	int GetCurrentValue() const noexcept override { return currentValue; }
 
 	// Returns changed=true if some values may have changed
 	FillResult<Sci::Position> FillRange(Sci::Position position, int value, Sci::Position fillLength) override;
@@ -108,15 +108,15 @@ public:
 
 	void DeleteLexerDecorations() override;
 
-	int AllOnFor(Sci::Position position) const override;
-	int ValueAt(int indicator, Sci::Position position) override;
-	Sci::Position Start(int indicator, Sci::Position position) override;
-	Sci::Position End(int indicator, Sci::Position position) override;
+	int AllOnFor(Sci::Position position) const noexcept override;
+	int ValueAt(int indicator, Sci::Position position) noexcept override;
+	Sci::Position Start(int indicator, Sci::Position position) noexcept override;
+	Sci::Position End(int indicator, Sci::Position position) noexcept override;
 
-	bool ClickNotified() const override {
+	bool ClickNotified() const noexcept override {
 		return clickNotified;
 	}
-	void SetClickNotified(bool notified) override {
+	void SetClickNotified(bool notified) noexcept override {
 		clickNotified = notified;
 	}
 };
@@ -132,7 +132,7 @@ DecorationList<POS>::~DecorationList() {
 }
 
 template <typename POS>
-Decoration<POS> *DecorationList<POS>::DecorationFromIndicator(int indicator) {
+Decoration<POS> *DecorationList<POS>::DecorationFromIndicator(int indicator) noexcept {
 	for (const std::unique_ptr<Decoration<POS>> &deco : decorationList) {
 		if (deco->Indicator() == indicator) {
 			return deco.get();
@@ -149,7 +149,7 @@ Decoration<POS> *DecorationList<POS>::Create(int indicator, Sci::Position length
 
 	typename std::vector<std::unique_ptr<Decoration<POS>>>::iterator it = std::lower_bound(
 		decorationList.begin(), decorationList.end(), decoNew,
-		[](const std::unique_ptr<Decoration<POS>> &a, const std::unique_ptr<Decoration<POS>> &b) {
+		[](const std::unique_ptr<Decoration<POS>> &a, const std::unique_ptr<Decoration<POS>> &b) noexcept {
 		return a->Indicator() < b->Indicator();
 	});
 	typename std::vector<std::unique_ptr<Decoration<POS>>>::iterator itAdded =
@@ -163,7 +163,7 @@ Decoration<POS> *DecorationList<POS>::Create(int indicator, Sci::Position length
 template <typename POS>
 void DecorationList<POS>::Delete(int indicator) {
 	decorationList.erase(std::remove_if(decorationList.begin(), decorationList.end(),
-		[indicator](const std::unique_ptr<Decoration<POS>> &deco) {
+		[indicator](const std::unique_ptr<Decoration<POS>> &deco) noexcept {
 		return deco->Indicator() == indicator;
 	}), decorationList.end());
 	current = nullptr;
@@ -228,7 +228,7 @@ void DecorationList<POS>::DeleteRange(Sci::Position position, Sci::Position dele
 template <typename POS>
 void DecorationList<POS>::DeleteLexerDecorations() {
 	decorationList.erase(std::remove_if(decorationList.begin(), decorationList.end(),
-		[](const std::unique_ptr<Decoration<POS>> &deco) {
+		[](const std::unique_ptr<Decoration<POS>> &deco) noexcept {
 		return deco->Indicator() < INDICATOR_CONTAINER ;
 	}), decorationList.end());
 	current = nullptr;
@@ -241,7 +241,7 @@ void DecorationList<POS>::DeleteAnyEmpty() {
 		decorationList.clear();
 	} else {
 		decorationList.erase(std::remove_if(decorationList.begin(), decorationList.end(),
-			[](const std::unique_ptr<Decoration<POS>> &deco) {
+			[](const std::unique_ptr<Decoration<POS>> &deco) noexcept {
 			return deco->Empty();
 		}), decorationList.end());
 	}
@@ -256,7 +256,7 @@ void DecorationList<POS>::SetView() {
 }
 
 template <typename POS>
-int DecorationList<POS>::AllOnFor(Sci::Position position) const {
+int DecorationList<POS>::AllOnFor(Sci::Position position) const noexcept {
 	int mask = 0;
 	for (const std::unique_ptr<Decoration<POS>> &deco : decorationList) {
 		if (deco->rs.ValueAt(static_cast<POS>(position))) {
@@ -269,7 +269,7 @@ int DecorationList<POS>::AllOnFor(Sci::Position position) const {
 }
 
 template <typename POS>
-int DecorationList<POS>::ValueAt(int indicator, Sci::Position position) {
+int DecorationList<POS>::ValueAt(int indicator, Sci::Position position) noexcept {
 	const Decoration<POS> *deco = DecorationFromIndicator(indicator);
 	if (deco) {
 		return deco->rs.ValueAt(static_cast<POS>(position));
@@ -278,7 +278,7 @@ int DecorationList<POS>::ValueAt(int indicator, Sci::Position position) {
 }
 
 template <typename POS>
-Sci::Position DecorationList<POS>::Start(int indicator, Sci::Position position) {
+Sci::Position DecorationList<POS>::Start(int indicator, Sci::Position position) noexcept {
 	const Decoration<POS> *deco = DecorationFromIndicator(indicator);
 	if (deco) {
 		return deco->rs.StartRun(static_cast<POS>(position));
@@ -287,7 +287,7 @@ Sci::Position DecorationList<POS>::Start(int indicator, Sci::Position position)
 }
 
 template <typename POS>
-Sci::Position DecorationList<POS>::End(int indicator, Sci::Position position) {
+Sci::Position DecorationList<POS>::End(int indicator, Sci::Position position) noexcept {
 	const Decoration<POS> *deco = DecorationFromIndicator(indicator);
 	if (deco) {
 		return deco->rs.EndRun(static_cast<POS>(position));
