@@ -5,6 +5,9 @@
 // Copyright 2018 by Neil Hodgson <neilh@scintilla.org>
 // The License.txt file describes the conditions under which this software may be distributed.
 
+#ifndef EDITORCONFIG_H
+#define EDITORCONFIG_H
+
 class FilePath;
 
 class IEditorConfig {
@@ -15,3 +18,5 @@ public:
 	virtual void Clear() = 0;
 	static std::unique_ptr<IEditorConfig> Create();
 };
+
+#endif
