@@ -20,6 +20,8 @@
 #include <memory>
 #include <chrono>
 #include <sstream>
+#include <atomic>
+#include <mutex>
 
 #include <fcntl.h>
 #include <sys/stat.h>
@@ -40,7 +42,6 @@
 #include "StyleWriter.h"
 #include "Extender.h"
 #include "SciTE.h"
-#include "Mutex.h"
 #include "JobQueue.h"
 #include "Cookie.h"
 #include "Worker.h"
