@@ -70,12 +70,12 @@ bool MarkerHandleSet::InsertHandle(int handle, int markerNum) {
 }
 
 void MarkerHandleSet::RemoveHandle(int handle) {
-	mhList.remove_if([handle](const MarkerHandleNumber &mhn) { return mhn.handle == handle; });
+	mhList.remove_if([handle](const MarkerHandleNumber &mhn) noexcept { return mhn.handle == handle; });
 }
 
 bool MarkerHandleSet::RemoveNumber(int markerNum, bool all) {
 	bool performedDeletion = false;
-	mhList.remove_if([&](const MarkerHandleNumber &mhn) {
+	mhList.remove_if([&](const MarkerHandleNumber &mhn) noexcept {
 		if ((all || !performedDeletion) && (mhn.number == markerNum)) {
 			performedDeletion = true;
 			return true;
@@ -102,6 +102,12 @@ void LineMarkers::InsertLine(Sci::Line line) {
 	}
 }
 
+void LineMarkers::InsertLines(Sci::Line line, Sci::Line lines) {
+	if (markers.Length()) {
+		markers.InsertEmpty(line, lines);
+	}
+}
+
 void LineMarkers::RemoveLine(Sci::Line line) {
 	// Retain the markers from the deleted line by oring them into the previous line
 	if (markers.Length()) {
@@ -219,7 +225,14 @@ void LineLevels::Init() {
 void LineLevels::InsertLine(Sci::Line line) {
 	if (levels.Length()) {
 		const int level = (line < levels.Length()) ? levels[line] : SC_FOLDLEVELBASE;
-		levels.InsertValue(line, 1, level);
+		levels.Insert(line, level);
+	}
+}
+
+void LineLevels::InsertLines(Sci::Line line, Sci::Line lines) {
+	if (levels.Length()) {
+		const int level = (line < levels.Length()) ? levels[line] : SC_FOLDLEVELBASE;
+		levels.InsertValue(line, lines, level);
 	}
 }
 
@@ -281,6 +294,14 @@ void LineState::InsertLine(Sci::Line line) {
 	}
 }
 
+void LineState::InsertLines(Sci::Line line, Sci::Line lines) {
+	if (lineStates.Length()) {
+		lineStates.EnsureLength(line);
+		const int val = (line < lineStates.Length()) ? lineStates[line] : 0;
+		lineStates.InsertValue(line, lines, val);
+	}
+}
+
 void LineState::RemoveLine(Sci::Line line) {
 	if (lineStates.Length() > line) {
 		lineStates.Delete(line);
@@ -343,6 +364,13 @@ void LineAnnotation::InsertLine(Sci::Line line) {
 	}
 }
 
+void LineAnnotation::InsertLines(Sci::Line line, Sci::Line lines) {
+	if (annotations.Length()) {
+		annotations.EnsureLength(line);
+		annotations.InsertEmpty(line, lines);
+	}
+}
+
 void LineAnnotation::RemoveLine(Sci::Line line) {
 	if (annotations.Length() && (line > 0) && (line <= annotations.Length())) {
 		annotations[line-1].reset();
@@ -459,6 +487,13 @@ void LineTabstops::InsertLine(Sci::Line line) {
 	}
 }
 
+void LineTabstops::InsertLines(Sci::Line line, Sci::Line lines) {
+	if (tabstops.Length()) {
+		tabstops.EnsureLength(line);
+		tabstops.InsertEmpty(line, lines);
+	}
+}
+
 void LineTabstops::RemoveLine(Sci::Line line) {
 	if (tabstops.Length() > line) {
 		tabstops[line].reset();
