@@ -5,20 +5,15 @@
 // Copyright 1998-2011 by Neil Hodgson <neilh@scintilla.org>
 // The License.txt file describes the conditions under which this software may be distributed.
 
+#ifndef SCITEBASE_H
+#define SCITEBASE_H
+
 extern const GUI::gui_char appName[];
 
 extern const GUI::gui_char propUserFileName[];
 extern const GUI::gui_char propGlobalFileName[];
 extern const GUI::gui_char propAbbrevFileName[];
 
-#ifdef _WIN32
-#ifdef _MSC_VER
-// Shut up level 4 warning:
-// warning C4800: forcing value to bool 'true' or 'false' (performance warning)
-#pragma warning(disable: 4800)
-#endif
-#endif
-
 inline int Minimum(int a, int b) noexcept {
 	return (a < b) ? a : b;
 }
@@ -362,6 +357,14 @@ public:
 class IEditorConfig;
 struct SCNotification;
 
+struct SystemAppearance {
+	bool dark;
+	bool highContrast;
+	bool operator==(const SystemAppearance &other) const noexcept {
+		return dark == other.dark && highContrast == other.highContrast;
+	}
+};
+
 class SciTEBase : public ExtensionAPI, public Searcher, public WorkerListener {
 protected:
 	bool needIdle;
@@ -370,11 +373,11 @@ protected:
 	FilePath dirNameAtExecute;
 	FilePath dirNameForExecute;
 
-	enum { fileStackMax = 10 };
+	static constexpr int fileStackMax = 10;
 	RecentFile recentFileStack[fileStackMax];
 	enum { fileStackCmdID = IDM_MRUFILE, bufferCmdID = IDM_BUFFER };
 
-	enum { importMax = 50 };
+	static constexpr int importMax = 50;
 	FilePathSet importFiles;
 	enum { importCmdID = IDM_IMPORT };
 	ImportFilter filter;
@@ -462,6 +465,7 @@ protected:
 	std::string foldHiliteColour;
 	bool openFilesHere;
 	bool fullScreen;
+	SystemAppearance appearance;
 	enum { toolMax = 50 };
 	Extension *extender;
 	bool needReadProperties;
@@ -588,6 +592,8 @@ protected:
 	void ReadLocalPropFile();
 	void ReadDirectoryPropFile();
 
+	virtual SystemAppearance CurrentAppearance() const noexcept;
+	void CheckAppearanceChanged();
 	void SetPaneFocus(bool editPane) noexcept;
 	GUI::ScintillaWindow &PaneFocused();
 	GUI::ScintillaWindow &PaneSource(int destination);
@@ -1001,7 +1007,7 @@ public:
 
 	GUI::WindowID GetID() const noexcept { return wSciTE.GetID(); }
 
-	virtual bool PerformOnNewThread(Worker *pWorker) = 0;
+	bool PerformOnNewThread(Worker *pWorker);
 	// WorkerListener
 	void PostOnMainThread(int cmd, Worker *pWorker) override = 0;
 	virtual void WorkerCommand(int cmd, Worker *pWorker);
@@ -1010,3 +1016,11 @@ public:
 int ControlIDOfCommand(unsigned long) noexcept;
 SA::Colour ColourOfProperty(const PropSetFile &props, const char *key, SA::Colour colourDefault);
 void WindowSetFocus(GUI::ScintillaWindow &w);
+
+// Test if an enum class value has the bit flag(s) of test set.
+template <typename T>
+constexpr bool FlagIsSet(T value, T test) {
+	return (static_cast<int>(value) & static_cast<int>(test)) == static_cast<int>(test);
+}
+
+#endif
