@@ -6,6 +6,7 @@
 // The License.txt file describes the conditions under which this software may be distributed.
 
 #include <cstdlib>
+#include <cassert>
 #include <cstring>
 
 #include <string>
@@ -13,18 +14,13 @@
 #include <map>
 #include <set>
 #include <algorithm>
-
-#include "Scintilla.h"
+#include <chrono>
 
 #include "GUI.h"
 #include "StringList.h"
 #include "StringHelpers.h"
 
-static inline bool IsASpace(unsigned int ch) {
-    return (ch == ' ') || ((ch >= 0x09) && (ch <= 0x0d));
-}
-
-static int CompareNCaseInsensitive(const char *a, const char *b, size_t len) {
+static int CompareNCaseInsensitive(const char *a, const char *b, size_t len) noexcept {
 	while (*a && *b && len) {
 		if (*a != *b) {
 			const char upperA = MakeUpperCase(*a);
@@ -90,11 +86,11 @@ void StringList::SetFromListText() {
 	wordsNoCase = words;
 }
 
-static bool CmpString(const char *a, const char *b) {
+static bool CmpString(const char *a, const char *b) noexcept {
 	return strcmp(a, b) < 0;
 }
 
-static bool CmpStringNoCase(const char *a, const char *b) {
+static bool CmpStringNoCase(const char *a, const char *b) noexcept {
 	return CompareNoCase(a, b) < 0;
 }
 
@@ -113,7 +109,7 @@ void StringList::SortIfNeeded(bool ignoreCase) {
 	}
 }
 
-void StringList::Clear() {
+void StringList::Clear() noexcept {
 	words.clear();
 	wordsNoCase.clear();
 	listText.clear();
@@ -138,22 +134,23 @@ namespace {
 
 struct CompareString {
 	size_t searchLen;
-	explicit CompareString(size_t searchLen_) : searchLen(searchLen_) {}
-	bool operator()(const char *a, const char *b) const {
+	explicit CompareString(size_t searchLen_) noexcept : searchLen(searchLen_) {}
+	bool operator()(const char *a, const char *b) const noexcept {
 		return strncmp(a, b, searchLen) < 0;
 	}
 };
 
 struct CompareStringInsensitive {
 	size_t searchLen;
-	explicit CompareStringInsensitive(size_t searchLen_) : searchLen(searchLen_) {}
-	bool operator()(const char *a, const char *b) const {
+	explicit CompareStringInsensitive(size_t searchLen_) noexcept : searchLen(searchLen_) {}
+	bool operator()(const char *a, const char *b) const noexcept {
 		return CompareNCaseInsensitive(a, b, searchLen) < 0;
 	}
 };
 
 template<typename Compare>
-	std::string GetMatch(std::vector<char *>::iterator start, std::vector<char *>::iterator end, const char *wordStart, const std::string &wordCharacters, int wordIndex, Compare comp) {
+std::string GetMatch(std::vector<char *>::iterator start, std::vector<char *>::iterator end,
+		     const char *wordStart, const std::string &wordCharacters, int wordIndex, Compare comp) {
 	std::vector<char *>::iterator elem = std::lower_bound(start, end, wordStart, comp);
 	if (!comp(wordStart, *elem) && !comp(*elem, wordStart)) {
 		// Found a matching element, now move forward wordIndex matching elements
@@ -195,7 +192,7 @@ std::string StringList::GetNearestWord(const char *wordStart, size_t searchLen,
  * there may be extra spaces after the identifier that should not be
  * counted in the length.
  */
-static size_t LengthWord(const char *word, char otherSeparator) {
+static size_t LengthWord(const char *word, char otherSeparator) noexcept {
 	const char *endWord = nullptr;
 	// Find an otherSeparator
 	if (otherSeparator)
@@ -205,6 +202,7 @@ static size_t LengthWord(const char *word, char otherSeparator) {
 		endWord = strchr(word, '(');
 	if (!endWord)
 		endWord = word + strlen(word);
+	assert(endWord);
 	// Last case always succeeds so endWord != 0
 
 	// Drop any space characters.
@@ -247,11 +245,11 @@ static std::string GetMatches(std::vector<char *>::iterator start, std::vector<c
  * them in the ascending order separated with spaces.
  */
 std::string StringList::GetNearestWords(
-    const char *wordStart,
-    size_t searchLen,
-    bool ignoreCase,
-    char otherSeparator /*= '\0'*/,
-    bool exactLen /*=false*/) {
+	const char *wordStart,
+	size_t searchLen,
+	bool ignoreCase,
+	char otherSeparator /*= '\0'*/,
+	bool exactLen /*=false*/) {
 
 	if (words.empty())
 		return std::string();
