@@ -81,7 +81,7 @@ Style::Style() : FontSpecification() {
 	      SC_WEIGHT_NORMAL, false, false, false, caseMixed, true, true, false);
 }
 
-Style::Style(const Style &source) : FontSpecification(), FontMeasurements() {
+Style::Style(const Style &source) noexcept : FontSpecification(), FontMeasurements() {
 	Clear(ColourDesired(0, 0, 0), ColourDesired(0xff, 0xff, 0xff),
 	      0, nullptr, 0,
 	      SC_WEIGHT_NORMAL, false, false, false, caseMixed, true, true, false);
@@ -103,7 +103,7 @@ Style::Style(const Style &source) : FontSpecification(), FontMeasurements() {
 Style::~Style() {
 }
 
-Style &Style::operator=(const Style &source) {
+Style &Style::operator=(const Style &source) noexcept {
 	if (this == &source)
 		return * this;
 	Clear(ColourDesired(0, 0, 0), ColourDesired(0xff, 0xff, 0xff),
@@ -128,7 +128,7 @@ void Style::Clear(ColourDesired fore_, ColourDesired back_, int size_,
         const char *fontName_, int characterSet_,
         int weight_, bool italic_, bool eolFilled_,
         bool underline_, ecaseForced caseForce_,
-        bool visible_, bool changeable_, bool hotspot_) {
+        bool visible_, bool changeable_, bool hotspot_) noexcept {
 	fore = fore_;
 	back = back_;
 	characterSet = characterSet_;
@@ -146,7 +146,7 @@ void Style::Clear(ColourDesired fore_, ColourDesired back_, int size_,
 	FontMeasurements::ClearMeasurements();
 }
 
-void Style::ClearTo(const Style &source) {
+void Style::ClearTo(const Style &source) noexcept {
 	Clear(
 	    source.fore,
 	    source.back,
@@ -163,7 +163,7 @@ void Style::ClearTo(const Style &source) {
 	    source.hotspot);
 }
 
-void Style::Copy(Font &font_, const FontMeasurements &fm_) {
+void Style::Copy(const Font &font_, const FontMeasurements &fm_) noexcept {
 	font.MakeAlias(font_);
 	(FontMeasurements &)(*this) = fm_;
 }
