@@ -5,18 +5,25 @@
 // Copyright 1998-2010 by Neil Hodgson <neilh@scintilla.org>
 // The License.txt file describes the conditions under which this software may be distributed.
 
+#include <cstdint>
+
 #include <string>
+#include <string_view>
+#include <chrono>
+
+#include "ScintillaTypes.h"
+#include "ScintillaCall.h"
 
-#include "Scintilla.h"
 #include "GUI.h"
-#include "ScintillaWindow.h"
 #include "StyleWriter.h"
 
-TextReader::TextReader(GUI::ScintillaWindow &sw_) :
+namespace SA = Scintilla::API;
+
+TextReader::TextReader(SA::ScintillaCall &sc_) noexcept :
 	startPos(extremePosition),
 	endPos(0),
 	codePage(0),
-	sw(sw_),
+	sc(sc_),
 	lenDoc(-1) {
 	buf[0] = 0;
 }
@@ -25,9 +32,9 @@ bool TextReader::InternalIsLeadByte(char ch) const {
 	return GUI::IsDBCSLeadByte(codePage, ch);
 }
 
-void TextReader::Fill(int position) {
+void TextReader::Fill(SA::Position position) {
 	if (lenDoc == -1)
-		lenDoc = sw.Call(SCI_GETTEXTLENGTH, 0, 0);
+		lenDoc = sc.Length();
 	startPos = position - slopSize;
 	if (startPos + bufferSize > lenDoc)
 		startPos = lenDoc - bufferSize;
@@ -36,11 +43,11 @@ void TextReader::Fill(int position) {
 	endPos = startPos + bufferSize;
 	if (endPos > lenDoc)
 		endPos = lenDoc;
-	sw.Call(SCI_SETTARGETRANGE, startPos, endPos);
-	sw.CallPointer(SCI_GETTARGETTEXT, 0, buf);
+	sc.SetTarget(SA::Range(startPos, endPos));
+	sc.TargetText(buf);
 }
 
-bool TextReader::Match(int pos, const char *s) {
+bool TextReader::Match(SA::Position pos, const char *s) {
 	for (int i=0; *s; i++) {
 		if (*s != SafeGetCharAt(pos+i))
 			return false;
@@ -49,62 +56,61 @@ bool TextReader::Match(int pos, const char *s) {
 	return true;
 }
 
-int TextReader::StyleAt(int position) {
-	return static_cast<unsigned char>(sw.Call(
-		SCI_GETSTYLEAT, position, 0));
+int TextReader::StyleAt(SA::Position position) {
+	return sc.UnsignedStyleAt(position);
 }
 
-int TextReader::GetLine(int position) {
-	return sw.Call(SCI_LINEFROMPOSITION, position, 0);
+SA::Line TextReader::GetLine(SA::Position position) {
+	return sc.LineFromPosition(position);
 }
 
-int TextReader::LineStart(int line) {
-	return sw.Call(SCI_POSITIONFROMLINE, line, 0);
+SA::Position TextReader::LineStart(SA::Line line) {
+	return sc.LineStart(line);
 }
 
-int TextReader::LevelAt(int line) {
-	return sw.Call(SCI_GETFOLDLEVEL, line, 0);
+SA::FoldLevel TextReader::LevelAt(SA::Line line) {
+	return sc.FoldLevel(line);
 }
 
-int TextReader::Length() {
+SA::Position TextReader::Length() {
 	if (lenDoc == -1)
-		lenDoc = sw.Call(SCI_GETTEXTLENGTH, 0, 0);
+		lenDoc = sc.Length();
 	return lenDoc;
 }
 
-int TextReader::GetLineState(int line) {
-	return sw.Call(SCI_GETLINESTATE, line);
+int TextReader::GetLineState(SA::Line line) {
+	return sc.LineState(line);
 }
 
-StyleWriter::StyleWriter(GUI::ScintillaWindow &sw_) :
-	TextReader(sw_),
+StyleWriter::StyleWriter(SA::ScintillaCall &sc_) noexcept :
+	TextReader(sc_),
 	validLen(0),
 	startSeg(0) {
 	styleBuf[0] = 0;
 }
 
-int StyleWriter::SetLineState(int line, int state) {
-	return sw.Call(SCI_SETLINESTATE, line, state);
+void StyleWriter::SetLineState(SA::Line line, int state) {
+	sc.SetLineState(line, state);
 }
 
-void StyleWriter::StartAt(unsigned int start, char chMask) {
-	sw.Call(SCI_STARTSTYLING, start, chMask);
+void StyleWriter::StartAt(SA::Position start, char chMask) {
+	sc.StartStyling(start, chMask);
 }
 
-void StyleWriter::StartSegment(unsigned int pos) {
+void StyleWriter::StartSegment(SA::Position pos) noexcept {
 	startSeg = pos;
 }
 
-void StyleWriter::ColourTo(unsigned int pos, int chAttr) {
+void StyleWriter::ColourTo(SA::Position pos, int chAttr) {
 	// Only perform styling if non empty range
 	if (pos != startSeg - 1) {
 		if (validLen + (pos - startSeg + 1) >= bufferSize)
 			Flush();
 		if (validLen + (pos - startSeg + 1) >= bufferSize) {
 			// Too big for buffer so send directly
-			sw.Call(SCI_SETSTYLING, pos - startSeg + 1, chAttr);
+			sc.SetStyling(pos - startSeg + 1, chAttr);
 		} else {
-			for (unsigned int i = startSeg; i <= pos; i++) {
+			for (SA::Position i = startSeg; i <= pos; i++) {
 				styleBuf[validLen++] = static_cast<char>(chAttr);
 			}
 		}
@@ -112,15 +118,15 @@ void StyleWriter::ColourTo(unsigned int pos, int chAttr) {
 	startSeg = pos+1;
 }
 
-void StyleWriter::SetLevel(int line, int level) {
-	sw.Call(SCI_SETFOLDLEVEL, line, level);
+void StyleWriter::SetLevel(SA::Line line, SA::FoldLevel level) {
+	sc.SetFoldLevel(line, level);
 }
 
 void StyleWriter::Flush() {
 	startPos = extremePosition;
 	lenDoc = -1;
 	if (validLen > 0) {
-		sw.CallPointer(SCI_SETSTYLINGEX, validLen, styleBuf);
+		sc.SetStylingEx(validLen, styleBuf);
 		validLen = 0;
 	}
 }
