@@ -12,7 +12,8 @@
 //   http://www.cl.cam.ac.uk/~mgk25/unicode.html
 ////////////////////////////////////////////////////////////////////////////////
 
-#include <cassert>
+#ifndef UTF8_16_H
+#define UTF8_16_H
 
 class Utf8_16 {
 public:
@@ -66,9 +67,7 @@ public:
 	void reset() noexcept;
 	void set(const ubyte *pBuf, size_t nLen, encodingType eEncoding);
 	int get() const noexcept {
-#ifdef _DEBUG
 		assert(m_eState == eStart);
-#endif
 		return m_nCur;
 	}
 	bool canGet() const noexcept { return m_eState == eStart; }
@@ -133,3 +132,5 @@ protected:
 	size_t m_nBufSize;
 	bool m_bFirstWrite;
 };
+
+#endif
