@@ -5,6 +5,9 @@
 // Copyright 1998-2001 by Neil Hodgson <neilh@scintilla.org>
 // The License.txt file describes the conditions under which this software may be distributed.
 
+#ifndef DIRECTOREXTENSION_H
+#define DIRECTOREXTENSION_H
+
 class DirectorExtension : public Extension {
 private:
 	ExtensionAPI *host {};
@@ -43,3 +46,4 @@ public:
 	void HandleStringMessage(const char *message);
 };
 
+#endif
