@@ -12,6 +12,7 @@
 
 #include <string>
 #include <vector>
+#include <chrono>
 #include <sstream>
 
 #ifdef __MINGW_H
@@ -22,7 +23,7 @@
 #define _WIN32_WINNT  0x0602
 #include <windows.h>
 
-#include "Scintilla.h"
+#include "ScintillaTypes.h"
 #include "GUI.h"
 
 namespace GUI {
@@ -31,7 +32,7 @@ enum { SURROGATE_LEAD_FIRST = 0xD800 };
 enum { SURROGATE_TRAIL_FIRST = 0xDC00 };
 enum { SURROGATE_TRAIL_LAST = 0xDFFF };
 
-static unsigned int UTF8Length(const wchar_t *uptr, size_t tlen) {
+static unsigned int UTF8Length(const wchar_t *uptr, size_t tlen) noexcept {
 	unsigned int len = 0;
 	for (size_t i = 0; i < tlen && uptr[i];) {
 		const unsigned int uch = uptr[i];
@@ -40,7 +41,7 @@ static unsigned int UTF8Length(const wchar_t *uptr, size_t tlen) {
 		} else if (uch < 0x800) {
 			len += 2;
 		} else if ((uch >= SURROGATE_LEAD_FIRST) &&
-			(uch <= SURROGATE_TRAIL_LAST)) {
+				(uch <= SURROGATE_TRAIL_LAST)) {
 			len += 4;
 			i++;
 		} else {
@@ -51,7 +52,7 @@ static unsigned int UTF8Length(const wchar_t *uptr, size_t tlen) {
 	return len;
 }
 
-static void UTF8FromUTF16(const wchar_t *uptr, size_t tlen, char *putf) {
+static void UTF8FromUTF16(const wchar_t *uptr, size_t tlen, char *putf) noexcept {
 	int k = 0;
 	for (size_t i = 0; i < tlen && uptr[i];) {
 		const unsigned int uch = uptr[i];
@@ -61,7 +62,7 @@ static void UTF8FromUTF16(const wchar_t *uptr, size_t tlen, char *putf) {
 			putf[k++] = static_cast<char>(0xC0 | (uch >> 6));
 			putf[k++] = static_cast<char>(0x80 | (uch & 0x3f));
 		} else if ((uch >= SURROGATE_LEAD_FIRST) &&
-			(uch <= SURROGATE_TRAIL_LAST)) {
+				(uch <= SURROGATE_TRAIL_LAST)) {
 			// Half a surrogate pair
 			i++;
 			const unsigned int xch = 0x10000 + ((uch & 0x3ff) << 10) + (uptr[i] & 0x3ff);
@@ -78,7 +79,7 @@ static void UTF8FromUTF16(const wchar_t *uptr, size_t tlen, char *putf) {
 	}
 }
 
-static size_t UTF16Length(const char *s, size_t len) {
+static size_t UTF16Length(const char *s, size_t len) noexcept {
 	size_t ulen = 0;
 	size_t charLen;
 	for (size_t i=0; i<len;) {
@@ -99,7 +100,7 @@ static size_t UTF16Length(const char *s, size_t len) {
 	return ulen;
 }
 
-static size_t UTF16FromUTF8(const char *s, size_t len, gui_char *tbuf, size_t tlen) {
+static size_t UTF16FromUTF8(const char *s, size_t len, gui_char *tbuf, size_t tlen) noexcept {
 	size_t ui=0;
 	const unsigned char *us = reinterpret_cast<const unsigned char *>(s);
 	size_t i=0;
@@ -169,28 +170,11 @@ std::string UTF8FromString(const gui_string &s) {
 }
 
 gui_string StringFromInteger(long i) {
-	char number[32];
-	sprintf(number, "%0ld", i);
-	gui_char gnumber[32];
-	size_t n=0;
-	while (number[n]) {
-		gnumber[n] = static_cast<gui_char>(number[n]);
-		n++;
-	}
-	gnumber[n] = 0;
-	return gui_string(gnumber);
+	return std::to_wstring(i);
 }
 
 gui_string StringFromLongLong(long long i) {
-	try {
-		std::ostringstream strstrm;
-		strstrm << i;
-		return StringFromUTF8(strstrm.str());
-	} catch (std::exception &) {
-		// Exceptions not enabled on stream but still causes diagnostic in Coverity.
-		// Simply swallow the failure and return the default value.
-	}
-	return gui_string();
+	return std::to_wstring(i);
 }
 
 gui_string HexStringFromInteger(long i) {
@@ -212,7 +196,7 @@ std::string LowerCaseUTF8(std::string_view sv) {
 	}
 	const std::string s(sv);
 	const gui_string gs = StringFromUTF8(s);
-	const int chars = ::LCMapString(LOCALE_SYSTEM_DEFAULT, LCMAP_LOWERCASE, gs.c_str(), static_cast<int>(gs.size()), NULL, 0);
+	const int chars = ::LCMapString(LOCALE_SYSTEM_DEFAULT, LCMAP_LOWERCASE, gs.c_str(), static_cast<int>(gs.size()), nullptr, 0);
 	gui_string lc(chars, L'\0');
 	::LCMapString(LOCALE_SYSTEM_DEFAULT, LCMAP_LOWERCASE, gs.c_str(), static_cast<int>(gs.size()), lc.data(), chars);
 	return UTF8FromString(lc);
@@ -236,11 +220,11 @@ Rectangle Window::GetPosition() {
 
 void Window::SetPosition(Rectangle rc) {
 	::SetWindowPos(static_cast<HWND>(wid),
-		0, rc.left, rc.top, rc.Width(), rc.Height(), SWP_NOZORDER|SWP_NOACTIVATE);
+		       0, rc.left, rc.top, rc.Width(), rc.Height(), SWP_NOZORDER|SWP_NOACTIVATE);
 }
 
 Rectangle Window::GetClientPosition() {
-	RECT rc={0,0,0,0};
+	RECT rc= {0, 0, 0, 0};
 	if (wid)
 		::GetClientRect(static_cast<HWND>(wid), &rc);
 	return  Rectangle(rc.left, rc.top, rc.right, rc.bottom);
@@ -254,7 +238,7 @@ void Window::Show(bool show) {
 }
 
 void Window::InvalidateAll() {
-	::InvalidateRect(static_cast<HWND>(wid), NULL, FALSE);
+	::InvalidateRect(static_cast<HWND>(wid), nullptr, FALSE);
 }
 
 void Window::SetTitle(const gui_char *s) {
@@ -274,65 +258,17 @@ void Menu::Destroy() {
 
 void Menu::Show(Point pt, Window &w) {
 	::TrackPopupMenu(static_cast<HMENU>(mid),
-		TPM_RIGHTBUTTON, pt.x - 4, pt.y, 0,
-		static_cast<HWND>(w.GetID()), NULL);
+			 TPM_RIGHTBUTTON, pt.x - 4, pt.y, 0,
+			 static_cast<HWND>(w.GetID()), NULL);
 	Destroy();
 }
 
-static bool initialisedET = false;
-static bool usePerformanceCounter = false;
-static LARGE_INTEGER frequency;
-
-ElapsedTime::ElapsedTime() {
-	if (!initialisedET) {
-		usePerformanceCounter = ::QueryPerformanceFrequency(&frequency) != 0;
-		initialisedET = true;
-	}
-	if (usePerformanceCounter) {
-		LARGE_INTEGER timeVal;
-		::QueryPerformanceCounter(&timeVal);
-		bigBit = timeVal.HighPart;
-		littleBit = timeVal.LowPart;
-	} else {
-		bigBit = clock();
-		littleBit = 0;
-	}
-}
-
-double ElapsedTime::Duration(bool reset) {
-	double result;
-	long endBigBit;
-	long endLittleBit;
-
-	if (usePerformanceCounter) {
-		LARGE_INTEGER lEnd;
-		::QueryPerformanceCounter(&lEnd);
-		endBigBit = lEnd.HighPart;
-		endLittleBit = lEnd.LowPart;
-		LARGE_INTEGER lBegin;
-		lBegin.HighPart = bigBit;
-		lBegin.LowPart = littleBit;
-		const double elapsed = static_cast<double>(lEnd.QuadPart - lBegin.QuadPart);
-		result = elapsed / static_cast<double>(frequency.QuadPart);
-	} else {
-		endBigBit = clock();
-		endLittleBit = 0;
-		const double elapsed = endBigBit - bigBit;
-		result = elapsed / CLOCKS_PER_SEC;
-	}
-	if (reset) {
-		bigBit = endBigBit;
-		littleBit = endLittleBit;
-	}
-	return result;
-}
-
-sptr_t ScintillaPrimitive::Send(unsigned int msg, uptr_t wParam, sptr_t lParam) {
+intptr_t ScintillaPrimitive::Send(unsigned int msg, uintptr_t wParam, intptr_t lParam) {
 	return ::SendMessage(static_cast<HWND>(GetID()), msg, wParam, lParam);
 }
 
 bool IsDBCSLeadByte(int codePage, char ch) {
-	if (SC_CP_UTF8 == codePage)
+	if (Scintilla::API::CpUtf8 == codePage)
 		// For lexing, all characters >= 0x80 are treated the
 		// same so none is considered a lead byte.
 		return false;
@@ -340,4 +276,8 @@ bool IsDBCSLeadByte(int codePage, char ch) {
 		return ::IsDBCSLeadByteEx(codePage, ch) != 0;
 }
 
+void SleepMilliseconds(int sleepTime) {
+	::Sleep(sleepTime);
+}
+
 }
