@@ -35,7 +35,7 @@ GUI::gui_string TextOfWindow(HWND hWnd) {
 GUI::gui_string ClassNameOfWindow(HWND hWnd) {
 	// In the documentation of WNDCLASS:
 	// "The maximum length for lpszClassName is 256."
-	const size_t maxClassNameLength = 256+1;	// +1 for NUL
+	constexpr size_t maxClassNameLength = 256+1;	// +1 for NUL
 	GUI::gui_char className[maxClassNameLength];
 	if (::GetClassNameW(hWnd, className, maxClassNameLength))
 		return GUI::gui_string(className);
@@ -63,13 +63,9 @@ void CheckButton(const GUI::Window &wButton, bool checked) noexcept {
 
 SIZE SizeButton(const GUI::Window &wButton) noexcept {
 	SIZE sz = { 0, 0 };
-#ifdef BCM_GETIDEALSIZE
 	// Push buttons can be measured with BCM_GETIDEALSIZE.
 	::SendMessage(HwndOf(wButton),
 		      BCM_GETIDEALSIZE, 0, reinterpret_cast<LPARAM>(&sz));
-#else
-	(void)wButton;	// Avoid warning from GCC
-#endif
 	return sz;
 }
 
@@ -364,9 +360,9 @@ bool Strip::KeyDown(WPARAM key) {
 			while (wChild) {
 				const GUI::gui_string className = ClassNameOfWindow(wChild);
 				if ((className == TEXT("Button")) || (className == TEXT("Static"))) {
-					const GUI::gui_string caption = TextOfWindow(wChild);
+					const std::string caption = GUI::UTF8FromString(TextOfWindow(wChild));
 					for (int i=0; caption[i]; i++) {
-						if ((caption[i] == L'&') && (toupper(caption[i+1]) == static_cast<int>(key))) {
+						if ((caption[i] == L'&') && (MakeUpperCase(caption[i+1]) == static_cast<int>(key))) {
 							if (className == TEXT("Button")) {
 								::SendMessage(wChild, BM_CLICK, 0, 0);
 							} else {	// Static caption
@@ -588,7 +584,7 @@ LRESULT Strip::CustomDraw(NMHDR *pnmh) noexcept {
 		rbmi.bmiHeader.biSize = sizeof(BITMAPINFOHEADER);
 		::GetDIBits(pcd->hdc, hBitmap, 0, 0, nullptr, &rbmi, DIB_RGB_COLORS);
 
-		const DWORD colourTransparent = RGB(0xC0, 0xC0, 0xC0);
+		constexpr DWORD colourTransparent = RGB(0xC0, 0xC0, 0xC0);
 
 		// Offset from button edge to contents.
 		const int xOffset = ((rcButton.right - rcButton.left) - rbmi.bmiHeader.biWidth) / 2 + 1;
@@ -779,7 +775,7 @@ void BackgroundStrip::Size() {
 	Strip::Size();
 	const GUI::Rectangle rcArea = LineArea(0);
 
-	const int progWidth = 200;
+	constexpr int progWidth = 200;
 
 	GUI::Rectangle rcProgress = rcArea;
 	rcProgress.right = rcProgress.left + progWidth;
@@ -828,12 +824,12 @@ void BackgroundStrip::SetProgress(const GUI::gui_string &explanation, size_t siz
 		::SetWindowTextW(HwndOf(wExplanation), explanation.c_str());
 	}
 	// Scale values by 1000 as PBM_SETRANGE32 limited to 32-bit
-	const int scaleProgress = 1000;
+	constexpr int scaleProgress = 1000;
 	::SendMessage(HwndOf(wProgress), PBM_SETRANGE32, 0, size/scaleProgress);
 	::SendMessage(HwndOf(wProgress), PBM_SETPOS, progress/scaleProgress, 0);
 }
 
-static const COLORREF colourNoMatch = RGB(0xff, 0x66, 0x66);
+static constexpr COLORREF colourNoMatch = RGB(0xff, 0x66, 0x66);
 
 void SearchStripBase::Creation() {
 	Strip::Creation();
