@@ -5,12 +5,8 @@
 // Copyright 2013 by Neil Hodgson <neilh@scintilla.org>
 // The License.txt file describes the conditions under which this software may be distributed.
 
-#ifndef UISF_HIDEACCEL
-#define UISF_HIDEACCEL 2
-#define UISF_HIDEFOCUS 1
-#define UIS_CLEAR 2
-#define UIS_SET 1
-#endif
+#ifndef STRIPS_H
+#define STRIPS_H
 
 void *PointerFromWindow(HWND hWnd) noexcept;
 void SetWindowPointer(HWND hWnd, void *ptr) noexcept;
@@ -238,3 +234,5 @@ public:
 	void SetList(int control, const char *value);
 	std::string GetValue(int control);
 };
+
+#endif
